@@ -157,21 +157,21 @@ def get_files(
     for src in sources:
         if src.parts[0] == '~':
             src = src.expanduser()
-        if src.is_dir():
+        # note: glob handled first, because e.g. on Windows asterisk makes is_dir unhappy
+        gs = str(src)
+        if '*' in gs:
+            if glob != DEFAULT_GLOB:
+                warnings.warn(f"{caller()}: treating {gs} as glob path. Explicit glob={glob} argument is ignored!")
+            paths.extend(map(Path, do_glob(gs)))
+        elif src.is_dir():
             gp: Iterable[Path] = src.glob(glob) # todo not sure if should be recursive?
             paths.extend(gp)
         else:
-            ss = str(src)
-            if '*' in ss:
-                if glob != DEFAULT_GLOB:
-                    warnings.warn(f"{caller()}: treating {ss} as glob path. Explicit glob={glob} argument is ignored!")
-                paths.extend(map(Path, do_glob(ss)))
-            else:
-                if not src.is_file():
-                    # todo not sure, might be race condition?
-                    raise RuntimeError(f"Expected '{src}' to exist")
-                # todo assert matches glob??
-                paths.append(src)
+            if not src.is_file():
+                # todo not sure, might be race condition?
+                raise RuntimeError(f"Expected '{src}' to exist")
+            # todo assert matches glob??
+            paths.append(src)
 
     if sort:
         paths = list(sorted(paths))
@@ -292,16 +292,6 @@ else:
     from .py37 import fromisoformat
 
 
-if sys.version_info[:2] >= (3, 8):
-    from typing import Literal
-else:
-    if TYPE_CHECKING:
-        from typing_extensions import Literal
-    else:
-        # erm.. I guess as long as it's not crashing, whatever...
-        Literal = Union
-
-
 # TODO doctests?
 def isoparse(s: str) -> tzdatetime:
     """
@@ -313,6 +303,8 @@ def isoparse(s: str) -> tzdatetime:
     s = s[:-1] + '+00:00'
     return fromisoformat(s)
 
+from .compat import Literal
+
 
 import re
 # https://stackoverflow.com/a/295466/706389
@@ -385,9 +377,16 @@ QUICK_STATS = False
 
 C = TypeVar('C')
 Stats = Dict[str, Any]
+StatsFun = Callable[[], Stats]
 # todo not sure about return type...
-def stat(func: Callable[[], Iterable[C]]) -> Stats:
-    fr = func()
+def stat(func: Union[Callable[[], Iterable[C]], Iterable[C]]) -> Stats:
+    if callable(func):
+        fr = func()
+        fname = func.__name__
+    else:
+        # meh. means it's just a list.. not sure how to generate a name then
+        fr = func
+        fname = f'unnamed_{id(fr)}'
     tname = type(fr).__name__
     if tname == 'DataFrame':
         # dynamic, because pandas is an optional dependency..
@@ -399,7 +398,7 @@ def stat(func: Callable[[], Iterable[C]]) -> Stats:
     else:
         res = _stat_iterable(fr)
     return {
-        func.__name__: res,
+        fname: res,
     }
 
 
@@ -449,14 +448,83 @@ def _stat_iterable(it: Iterable[C]) -> Any:
     return res
 
 
+def test_stat_iterable() -> None:
+    from datetime import datetime, timedelta
+    from typing import NamedTuple
+
+    dd = datetime.utcfromtimestamp(123)
+    day = timedelta(days=3)
+
+    X = NamedTuple('X', [('x', int), ('d', datetime)])
+
+    def it():
+        yield RuntimeError('oops!')
+        for i in range(2):
+            yield X(x=i, d=dd + day * i)
+        yield RuntimeError('bad!')
+        for i in range(3):
+            yield X(x=i * 10, d=dd + day * (i * 10))
+        yield X(x=123, d=dd + day * 50)
+
+    res = _stat_iterable(it())
+    assert res['count']  == 1 + 2 + 1 + 3 + 1
+    assert res['errors'] == 1 + 1
+    assert res['last'] == dd + day * 50
+
+
 # experimental, not sure about it..
 def guess_datetime(x: Any) -> Optional[datetime]:
-    # todo support datacalsses
-    asdict = getattr(x, '_asdict', None)
-    if asdict is None:
+    # todo hmm implement withoutexception..
+    try:
+        d = asdict(x)
+    except:
         return None
-    # todo check if there are multiple?
-    for k, v in asdict().items():
+    for k, v in d.items():
         if isinstance(v, datetime):
             return v
     return None
+
+def test_guess_datetime() -> None:
+    from datetime import datetime
+    from dataclasses import dataclass
+    from typing import NamedTuple
+
+    dd = isoparse('2021-02-01T12:34:56Z')
+
+    # ugh.. https://github.com/python/mypy/issues/7281
+    A = NamedTuple('A', [('x', int)])
+    B = NamedTuple('B', [('x', int), ('created', datetime)])
+
+    assert guess_datetime(A(x=4)) is None
+    assert guess_datetime(B(x=4, created=dd)) == dd
+
+    @dataclass
+    class C:
+        a: datetime
+        x: int
+    assert guess_datetime(C(a=dd, x=435)) == dd
+    # TODO not sure what to return when multiple datetime fields?
+    # TODO test @property?
+
+
+def asdict(thing) -> Json:
+    # todo primitive?
+    # todo exception?
+    if isinstance(thing, dict):
+        return thing
+    import dataclasses as D
+    if D.is_dataclass(thing):
+        return D.asdict(thing)
+    # must be a NT otherwise?
+    # todo add a proper check.. ()
+    return thing._asdict()
+
+
+# todo not sure about naming
+def to_jsons(it) -> Iterable[Json]:
+    from .error import error_to_json # prevent circular import
+    for r in it:
+        if isinstance(r, Exception):
+            yield error_to_json(r)
+        else:
+            yield asdict(r)
