@@ -5,12 +5,9 @@ import os
 import pkgutil
 import re
 import sys
-from typing import List, Iterable, NamedTuple, Optional
+from typing import List, Iterable, Optional
 
-
-class HPIModule(NamedTuple):
-    name: str
-    skip_reason: Optional[str]
+from .discovery_pure import HPIModule, ignored, _is_not_module_src, has_stats
 
 
 def modules() -> Iterable[HPIModule]:
@@ -19,17 +16,8 @@ def modules() -> Iterable[HPIModule]:
         yield m
 
 
-def ignored(m: str) -> bool:
-    excluded = [
-        # legacy stuff left for backwards compatibility
-        'core.*',
-        'config.*',
-    ]
-    exs = '|'.join(excluded)
-    return re.match(f'^my.({exs})$', m) is not None
-
-
-def get_stats(module: str):
+from .common import StatsFun
+def get_stats(module: str) -> Optional[StatsFun]:
     # todo detect via ast?
     try:
         mod = import_module(module)
@@ -40,40 +28,46 @@ def get_stats(module: str):
 
 
 __NOT_HPI_MODULE__ = 'Import this to mark a python file as a helper, not an actual HPI module'
-
-def has_not_module_flag(module: str) -> bool:
-    # if module == 'my.books.kobo':
-    #     breakpoint()
-    #     pass
-    try:
-        mod = import_module(module)
-    except Exception as e:
-        return False
-
-    return any(x is __NOT_HPI_MODULE__ for x in vars(mod).values())
+from .discovery_pure import NOT_HPI_MODULE_VAR
+assert NOT_HPI_MODULE_VAR in globals()  # check name consistency
 
 def is_not_hpi_module(module: str) -> Optional[str]:
-    # None if a module, otherwise returns reason
-    if has_not_module_flag(module):
-        return "marked explicitly (via __NOT_HPI_MODULE__)"
-    stats = get_stats(module)
-    if stats is None:
+    '''
+    None if a module, otherwise returns reason
+    '''
+    import importlib
+    path: Optional[str] = None
+    try:
+        # TODO annoying, this can cause import of the parent module?
+        spec = importlib.util.find_spec(module)
+        assert spec is not None
+        path = spec.origin
+    except Exception as e:
+        # todo a bit misleading.. it actually shouldn't import in most cases, it's just the weird parent module import thing
+        return "import error (possibly missing config entry)"  # todo add exc message?
+    assert path is not None # not sure if can happen?
+    if _is_not_module_src(Path(path)):
+        return f"marked explicitly (via {NOT_HPI_MODULE_VAR})"
+
+    if not has_stats(Path(path)):
         return "has no 'stats()' function"
     return None
 
+
+from types import ModuleType
 # todo reuse in readme/blog post
 # borrowed from https://github.com/sanitizers/octomachinery/blob/24288774d6dcf977c5033ae11311dbff89394c89/tests/circular_imports_test.py#L22-L55
-def _iter_all_importables(pkg) -> Iterable[HPIModule]:
+def _iter_all_importables(pkg: ModuleType) -> Iterable[HPIModule]:
     # todo crap. why does it include some stuff three times??
     yield from chain.from_iterable(
         _discover_path_importables(Path(p), pkg.__name__)
         # todo might need to handle __path__ for individual modules too?
         # not sure why __path__ was duplicated, but it did happen..
-        for p in set(pkg.__path__)
+        for p in set(pkg.__path__)  # type: ignore[attr-defined]
     )
 
 
-def _discover_path_importables(pkg_pth, pkg_name) -> Iterable[HPIModule]:
+def _discover_path_importables(pkg_pth: Path, pkg_name: str) -> Iterable[HPIModule]:
     from .core_config import config
 
     """Yield all importables under a given path and package."""
@@ -107,11 +101,11 @@ def _discover_path_importables(pkg_pth, pkg_name) -> Iterable[HPIModule]:
 # TODO when do we need to recurse?
 
 
-def _walk_packages(path=None, prefix='', onerror=None) -> Iterable[HPIModule]:
-    '''
+def _walk_packages(path: Iterable[str], prefix: str='', onerror=None) -> Iterable[HPIModule]:
+    """
     Modified version of https://github.com/python/cpython/blob/d50a0700265536a20bcce3fb108c954746d97625/Lib/pkgutil.py#L53,
     to alvoid importing modules that are skipped
-    '''
+    """
     from .core_config import config
 
     def seen(p, m={}):
@@ -121,6 +115,9 @@ def _walk_packages(path=None, prefix='', onerror=None) -> Iterable[HPIModule]:
 
     for info in pkgutil.iter_modules(path, prefix):
         mname = info.name
+        if mname is None:
+            # why would it be? anyway makes mypy happier
+            continue
 
         if ignored(mname):
             # not sure if need to yield?
@@ -136,7 +133,7 @@ def _walk_packages(path=None, prefix='', onerror=None) -> Iterable[HPIModule]:
             if is_not_module is not None:
                 skip_reason = is_not_module
 
-        else: # active is True
+        else:  # active is True
             # nothing to do, enabled explicitly
             pass
 
@@ -172,13 +169,14 @@ def get_modules() -> List[HPIModule]:
     return list(modules())
 
 
-
 ### tests start
 
 ## FIXME: add test when there is an import error -- should be defensive and yield exception
 
+
 def test_module_detection() -> None:
     from .core_config import _reset_config as reset
+
     with reset() as cc:
         cc.disabled_modules = ['my.location.*', 'my.body.*', 'my.workouts.*', 'my.private.*']
         mods = {m.name: m for m in modules()}
@@ -189,9 +187,67 @@ def test_module_detection() -> None:
         cc.enabled_modules  = ['my.demo']
         mods = {m.name: m for m in modules()}
 
-        assert mods['my.demo']  .skip_reason is None # not skipped
+        assert mods['my.demo']  .skip_reason is None  # not skipped
         assert mods['my.lastfm'].skip_reason == "suppressed in the user config"
 
 
+def test_good_modules(tmp_path: Path) -> None:
+    badp = tmp_path / 'good'
+    par = badp / 'my'
+    par.mkdir(parents=True)
+
+    (par / 'good.py').write_text('def stats(): pass')
+    (par / 'disabled.py').write_text('''
+from my.core import __NOT_HPI_MODULE__
+''')
+    (par / 'nostats.py').write_text('''
+# no stats!
+''')
+
+    import sys
+    orig_path = list(sys.path)
+    try:
+        sys.path.insert(0, str(badp))
+        good     = is_not_hpi_module('my.good')
+        disabled = is_not_hpi_module('my.disabled')
+        nostats  = is_not_hpi_module('my.nostats')
+    finally:
+        sys.path = orig_path
+
+    assert good is None # good module!
+    assert disabled is not None
+    assert 'marked explicitly' in disabled
+    assert nostats is not None
+    assert 'stats' in nostats
+
+
+def test_bad_modules(tmp_path: Path) -> None:
+    xx = tmp_path / 'precious_data'
+    xx.write_text('some precious data')
+    badp = tmp_path / 'bad'
+    par = badp / 'my'
+    par.mkdir(parents=True)
+
+    (par / 'malicious.py').write_text(f'''
+from pathlib import Path
+Path('{xx}').write_text('aaand your data is gone!')
+
+raise RuntimeError("FAIL ON IMPORT! naughy.")
+
+def stats():
+    return [1, 2, 3]
+''')
+
+    import sys
+    orig_path = list(sys.path)
+    try:
+        sys.path.insert(0, str(badp))
+        res = is_not_hpi_module('my.malicious')
+    finally:
+        sys.path = orig_path
+    # shouldn't crash at least
+    assert res is None  # good as far as discovery is concerned
+    assert xx.read_text() == 'some precious data'  # make sure module wasn't evauluated
+
 
 ### tests end
