@@ -1,6 +1,9 @@
 """
 Github data: events, comments, etc. (API data)
 """
+REQUIRES = [
+    'git+https://github.com/karlicoss/ghexport',
+]
 from dataclasses import dataclass
 from typing import Optional
 
@@ -17,40 +20,29 @@ class github(user_config):
     # path[s]/glob to the exported JSON data
     export_path: Paths
 
-    # path to a local clone of ghexport
-    # alternatively, you can put the repository (or a symlink) in $MY_CONFIG/my/config/repos/ghexport
-    ghexport : Optional[PathIsh] = None
-
     # path to a cache directory
     # if omitted, will use /tmp
     cache_dir: Optional[PathIsh] = None
-
-    @property
-    def dal_module(self):
-        rpath = self.ghexport
-        if rpath is not None:
-            from ..core.common import import_dir
-            return import_dir(rpath, '.dal')
-        else:
-            import my.config.repos.ghexport.dal as dal
-            return dal
 ###
 
 # TODO  perhaps using /tmp in case of None isn't ideal... maybe it should be treated as if cache is off
 
 from ..core.cfg import make_config, Attrs
 def migration(attrs: Attrs) -> Attrs:
-    if 'export_dir' in attrs: # legacy name
-        attrs['export_path'] = attrs['export_dir']
+    export_dir = 'export_dir'
+    if export_dir in attrs: # legacy name
+        attrs['export_path'] = attrs[export_dir]
+        from ..core.warnings import high
+        high(f'"{export_dir}" is deprecated! Please use "export_path" instead."')
     return attrs
 config = make_config(github, migration=migration)
 
 
-from typing import TYPE_CHECKING
-if TYPE_CHECKING:
-    import my.config.repos.ghexport.dal as dal
-else:
-    dal = config.dal_module
+try:
+    from ghexport import dal
+except ModuleNotFoundError as e:
+    from ..core.compat import pre_pip_dal_handler
+    dal = pre_pip_dal_handler('ghexport', e, config, requires=REQUIRES)
 
 ############################
 
@@ -76,7 +68,10 @@ def _dal() -> dal.DAL:
 @mcachew(config.cache_dir, hashf=lambda dal: dal.sources)
 def events(dal=_dal()) -> Results:
     for d in dal.events():
-        yield _parse_event(d)
+        if isinstance(d, Exception):
+            yield d
+        else:
+            yield _parse_event(d)
 
 
 def stats():
@@ -89,7 +84,7 @@ def stats():
 # TODO hmm. need some sort of abstract syntax for this...
 # TODO split further, title too
 def _get_summary(e) -> Tuple[str, Optional[str], Optional[str]]:
-    # TODO would be nice to give access to raw event withing timeline
+    # TODO would be nice to give access to raw event within timeline
     eid = e['id']
     tp = e['type']
     pl = e['payload']
