@@ -3,9 +3,13 @@ Module for locating and accessing [[https://takeout.google.com][Google Takeout]]
 '''
 
 from dataclasses import dataclass
-from ...core.common import Paths
+from ...core.common import Paths, get_files
+from ...core.util import __NOT_HPI_MODULE__
 
 from my.config import google as user_config
+
+from more_itertools import last
+
 @dataclass
 class google(user_config):
     takeout_path: Paths # path/paths/glob for the takeout zips
@@ -19,8 +23,7 @@ config = make_config(google)
 from pathlib import Path
 from typing import Optional, Iterable
 
-from ...common import get_files
-from ...kython.kompress import kopen, kexists
+from ...core.kompress import kopen, kexists
 
 
 def get_takeouts(*, path: Optional[str]=None) -> Iterable[Path]:
@@ -34,10 +37,8 @@ def get_takeouts(*, path: Optional[str]=None) -> Iterable[Path]:
             yield takeout
 
 
-def get_last_takeout(*, path: Optional[str]=None) -> Path:
-    # TODO more_itertools?
-    matching = list(get_takeouts(path=path))
-    return matching[-1]
+def get_last_takeout(*, path: Optional[str]=None) -> Optional[Path]:
+    return last(get_takeouts(path=path), default=None)
 
 
 # TODO might be a good idea to merge across multiple takeouts...
