@@ -10,6 +10,9 @@ we can run against the tests in my.core directly.
 
 '''
 
-from my.core.core_config import *
-from my.core.error       import *
-from my.core.util        import *
+from my.core.cfg            import *
+from my.core.common         import *
+from my.core.core_config    import *
+from my.core.error          import *
+from my.core.util           import *
+from my.core.discovery_pure import *
