@@ -20,6 +20,18 @@ def test() -> None:
 
 @pytest.fixture(autouse=True)
 def prepare(tmp_path: Path):
+    from .common import reset_modules
+    reset_modules()
+
+    user_config = _prepare_google_config(tmp_path)
+
+    import my.core.cfg as C
+    with C.tmp_config() as config:
+        config.google = user_config # type: ignore
+        yield
+
+
+def _prepare_google_config(tmp_path: Path):
     testdata = Path(__file__).absolute().parent.parent / 'testdata'
     assert testdata.exists(), testdata
 
@@ -30,8 +42,6 @@ def prepare(tmp_path: Path):
     with zipfile.ZipFile(tmp_path / 'takeout.zip', 'w') as zf:
         zf.writestr('Takeout/Location History/Location History.json', track.read_bytes())
 
-    from my.cfg import config
-    class user_config:
+    class google_config:
         takeout_path = tmp_path
-    config.google = user_config # type: ignore
-    yield
+    return google_config
