@@ -5,7 +5,7 @@ import lzma
 import io
 import zipfile
 
-from my.kython.kompress import kopen, kexists, CPath
+from my.core.kompress import kopen, kexists, CPath
 
 def test_kopen(tmp_path: Path) -> None:
     "Plaintext handled transparently"
@@ -46,10 +46,6 @@ def prepare(tmp_path: Path):
         pass
 
 
-# meh
-from my.core.error import test_sort_res_by
-
-
 from typing import Iterable, List
 import warnings
 from my.core import warn_if_empty
